@@ -2,8 +2,8 @@ from enum import Enum
 
 
 class ModelType(Enum):
-    """Class that contains model types
-    """  # noqa
+    """Class that contains model types"""
+
     TENSORFLOW = 0
     PYTORCH = 1
     SKLEARN = 2
@@ -11,3 +11,4 @@ class ModelType(Enum):
     ONNX = 4
     TRITON = 5
     CUSTOM = 6
+    LIGHTGBM = 7
