@@ -1,4 +1,4 @@
-from typing import Optional, List, Any, Dict
+from typing import Dict, Optional, Union
 
 from pydantic import BaseModel
 
@@ -6,17 +6,17 @@ from deeploy.common.functions import to_lower_camel
 
 
 class Deployment(BaseModel):
-    name: str
-    active_version: Optional[Dict]
-    workspace_id: str
-    description: Optional[str]
-    example_input: Optional[List[Any]]
-    example_output: Optional[List[Any]]
-    status: int
-    owner_id: str
-    kf_serving_id: Optional[str]
-    public_url: Optional[str]
     id: str
+    team_id: str
+    name: str
+    workspace_id: str
+    owner_id: str
+    public_url: Optional[str]
+    description: Optional[str]
+    active_version: Optional[Union[Dict, str]]
+    updating_to: Optional[Union[Dict, str]]
+    last_version: Optional[Union[Dict, str]]
+    status: int
     created_at: str
     updated_at: str
 
