@@ -7,9 +7,9 @@ from deeploy.common.functions import to_lower_camel
 
 class Repository(BaseModel):
     id: str
+    team_id: str
     name: str
     status: int
-    is_archived: bool
     workspace_id: str
     is_public: Optional[bool]
     remote_path: str
